@@ -29,6 +29,7 @@
 from __future__ import annotations
 
 import datetime as dt
+import enum
 import typing as t
 from dataclasses import dataclass
 
@@ -38,6 +39,20 @@ from chatto.channel import Channel
 from chatto.stream import Stream
 
 
+class MessageType(enum.Enum):
+    CHAT_ENDED_EVENT = "chatEndedEvent"
+    MESSAGE_DELETED_EVENT = "messageDeletedEvent"
+    NEW_SPONSOR_EVENT = "newSponsorEvent"
+    SPONSOR_ONLY_MODE_ENDED_EVENT = "sponsorOnlyModeEndedEvent"
+    SPONSOR_ONLY_MODE_STARTED_EVENT = "sponsorOnlyModeStartedEvent"
+    MEMBER_MILESTONE_CHAT_EVENT = "memberMilestoneChatEvent"
+    SUPER_CHAT_EVENT = "superChatEvent"
+    SUPER_STICKER_EVENT = "superStickerEvent"
+    TEXT_MESSAGE_EVENT = "textMessageEvent"
+    TOMBSTONE = "tombstone"
+    USER_BANNED_EVENT = "userBannedEvent"
+
+
 @dataclass(eq=True, frozen=True)
 class Message:
     """A dataclass representing a message. All class variables are also
@@ -46,11 +61,11 @@ class Message:
     id: str
     """The message's ID."""
 
-    type: str
+    type: MessageType
     """The message's type."""
 
     stream: Stream
-    """The stream instance the """
+    """The stream in which the bot is connected to."""
 
     channel: Channel
     """The channel in which the message was sent."""
@@ -74,13 +89,13 @@ class Message:
             connected to.
 
         ## Returns
-        * `Message`:
+        * `Message` -
             The newly created message object.
         """
         snippet = resource["snippet"]
         return cls(
             id=resource["id"],
-            type=snippet["type"],
+            type=MessageType(snippet["type"]),
             stream=stream,
             channel=Channel.from_author(resource["authorDetails"]),
             published_at=parse_ts(snippet["publishedAt"]),
