@@ -46,27 +46,65 @@ log = logging.getLogger(__name__)
 
 @dataclass(eq=True, frozen=True)
 class Stream:
+    """A dataclass representing a stream. All class variables are also
+    parameters that should be passed into the constructor."""
+
     id: str
+    """The stream ID."""
+
     chat_id: str
+    """The stream's active live chat ID."""
+
     start_time: dt.datetime
+    """The actual start time of the stream."""
 
     @classmethod
-    def from_data(cls, data: dict[str, t.Any]) -> Stream:
-        streaming_details = data["liveStreamingDetails"]
+    def from_youtube(cls, resource: dict[str, t.Any]) -> Stream:
+        """Create a `Stream` object from a video resource from the
+        YouTube Data API.
+
+        ## Arguments
+        * `resource` -
+            The video resource.
+
+        ## Returns
+        * `Stream` -
+            The newly created stream object.
+        """
+        streaming_details = resource["liveStreamingDetails"]
         chat_id = streaming_details.get("activeLiveChatId", None)
         if not chat_id:
             raise ChannelNotLive("the stream has no active chat ID")
         start_time = parse_ts(streaming_details["actualStartTime"])
 
-        log.info(f"Retrieved stream info for stream {data['id']}")
-        return cls(data["id"], chat_id, start_time)
+        log.info(f"Retrieved stream info for stream {resource['id']}")
+        return cls(resource["id"], chat_id, start_time)
 
     @staticmethod
     async def fetch_stream_data(
-        stream_id: str, token: str, session: ClientSession
+        stream_id: str, api_key: str, session: ClientSession
     ) -> dict[str, t.Any]:
+        """A helper method for fetching a video resource for a given
+        stream.
+
+        ## Arguments
+        * `stream_id` -
+            The ID of the stream to fetch info for.
+        * `api_key` -
+            The API key the bot is using.
+        * `session` -
+            The aiohttp session the bot is using.
+
+        ## Returns
+        * `dict` -
+            A video resource for the given stream.
+
+        ## Raises
+        * `HTTPError` -
+            The API request is invalid.
+        """
         url = chatto.YOUTUBE_API_BASE_URL + (
-            f"/videos?key={token}&part=liveStreamingDetails&id={stream_id}"
+            f"/videos?key={api_key}&part=liveStreamingDetails&id={stream_id}"
         )
 
         async with session.get(url) as r:
@@ -82,6 +120,25 @@ class Stream:
     async def fetch_active_stream_data(
         channel_id: str, token: str, session: ClientSession
     ) -> dict[str, t.Any]:
+        """A helper method for fetching a video resource for the given
+        channel's active stream.
+
+        ## Arguments
+        * `channel_id` -
+            The ID of the channel to fetch stream info for.
+        * `api_key` -
+            The API key the bot is using.
+        * `session` -
+            The aiohttp session the bot is using.
+
+        ## Returns
+        * `dict` -
+            A video resource for the given channel's stream.
+
+        ## Raises
+        * `HTTPError` -
+            The API request is invalid.
+        """
         url = chatto.YOUTUBE_API_BASE_URL + (
             "/search"
             f"?key={token}"
